@@ -32,7 +32,7 @@ class Family(object):
 
     See Also
     --------
-    :ref:`links`
+    :ref:`links` : Further details on links.
     """
     # TODO: change these class attributes, use valid somewhere...
     valid = [-np.inf, np.inf]
@@ -93,12 +93,12 @@ class Family(object):
 
         Parameters
         ----------
-        y : array
+        y : ndarray
             The untransformed response variable.
 
         Returns
         -------
-        mu_0 : array
+        mu_0 : ndarray
             The first guess on the transformed response variable.
 
         Notes
@@ -117,12 +117,12 @@ class Family(object):
 
         Parameters
         ----------
-        mu : array-like
+        mu : array_like
             The transformed mean response variable in the exponential family
 
         Returns
         -------
-        w : array
+        w : ndarray
             The weights for the IRLS steps
 
         Notes
@@ -142,20 +142,20 @@ class Family(object):
 
         Parameters
         ----------
-        endog : array-like
+        endog : array_like
             The endogenous response variable
-        mu : array-like
+        mu : array_like
             The inverse of the link function at the linear predicted values.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
-        freq_weights : array-like
+        freq_weights : array_like
             1d array of frequency weights. The default is 1.
         scale : float, optional
             An optional scale argument. The default is 1.
 
         Returns
         -------
-        Deviance : array
+        Deviance : ndarray
             The value of deviance function defined below.
 
         Notes
@@ -184,11 +184,11 @@ class Family(object):
 
         Parameters
         ----------
-        endog : array-like
+        endog : array_like
             The endogenous response variable
-        mu : array-like
+        mu : array_like
             The inverse of the link function at the linear predicted values.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float, optional
             An optional scale argument. The default is 1.
@@ -220,13 +220,13 @@ class Family(object):
 
         Parameters
         ----------
-        lin_pred : array
+        lin_pred : ndarray
             Values of the linear predictor of the model.
             :math:`X \cdot \beta` in a classical linear model.
 
         Returns
         -------
-        mu : array
+        mu : ndarray
             The mean response variables given by the inverse of the link
             function.
         """
@@ -239,12 +239,12 @@ class Family(object):
 
         Parameters
         ----------
-        mu : array
+        mu : ndarray
             The mean response variables
 
         Returns
         -------
-        lin_pred : array
+        lin_pred : ndarray
             Linear predictors based on the mean response variables.  The value
             of the link function at the given mu.
         """
@@ -257,11 +257,11 @@ class Family(object):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             Usually the endogenous response variable.
-        mu : array
+        mu : ndarray
             Usually but not always the fitted mean response variable.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float
             The scale parameter. The default is 1.
@@ -287,13 +287,13 @@ class Family(object):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             Usually the endogenous response variable.
-        mu : array
+        mu : ndarray
             Usually but not always the fitted mean response variable.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
-        freq_weights : array-like
+        freq_weights : array_like
             1d array of frequency weights. The default is 1.
         scale : float
             The scale parameter. The default is 1.
@@ -325,11 +325,11 @@ class Family(object):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float, optional
             An optional argument to divide the residuals by sqrt(scale).
@@ -389,8 +389,8 @@ class Poisson(Family):
 
     See Also
     --------
-    statsmodels.genmod.families.family.Family
-    :ref:`links`
+    statsmodels.genmod.families.family.Family : Parent class for all links.
+    :ref:`links` : Further details on links.
     """
     links = [L.log, L.identity, L.sqrt]
     variance = V.mu
@@ -408,9 +408,9 @@ class Poisson(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable.
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
 
         Returns
@@ -436,11 +436,11 @@ class Poisson(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             Usually the endogenous response variable.
-        mu : array
+        mu : ndarray
             Usually but not always the fitted mean response variable.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float
             The scale parameter. The default is 1.
@@ -466,11 +466,11 @@ class Poisson(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float, optional
             An optional argument to divide the residuals by sqrt(scale).
@@ -478,8 +478,8 @@ class Poisson(Family):
 
         Returns
         -------
-        resid_anscombe : array
-            The Anscome residuals for the Poisson family defined below
+        resid_anscombe : ndarray
+            The Anscombe residuals for the Poisson family defined below
 
         Notes
         -----
@@ -515,8 +515,8 @@ class Gaussian(Family):
 
     See Also
     --------
-    statsmodels.genmod.families.family.Family
-    :ref:`links`
+    statsmodels.genmod.families.family.Family : Parent class for all links.
+    :ref:`links` : Further details on links.
     """
 
     links = [L.log, L.identity, L.inverse_power]
@@ -534,9 +534,9 @@ class Gaussian(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable.
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
 
         Returns
@@ -559,11 +559,11 @@ class Gaussian(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             Usually the endogenous response variable.
-        mu : array
+        mu : ndarray
             Usually but not always the fitted mean response variable.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float
             The scale parameter. The default is 1.
@@ -608,11 +608,11 @@ class Gaussian(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float, optional
             An optional argument to divide the residuals by sqrt(scale).
@@ -620,7 +620,7 @@ class Gaussian(Family):
 
         Returns
         -------
-        resid_anscombe : array
+        resid_anscombe : ndarray
             The Anscombe residuals for the Gaussian family defined below
 
         Notes
@@ -659,8 +659,8 @@ class Gamma(Family):
 
     See Also
     --------
-    statsmodels.genmod.families.family.Family
-    :ref:`links`
+    statsmodels.genmod.families.family.Family : Parent class for all links.
+    :ref:`links` : Further details on links.
     """
     links = [L.log, L.identity, L.inverse_power]
     variance = V.mu_squared
@@ -677,9 +677,9 @@ class Gamma(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable.
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
 
         Returns
@@ -705,11 +705,11 @@ class Gamma(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             Usually the endogenous response variable.
-        mu : array
+        mu : ndarray
             Usually but not always the fitted mean response variable.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float
             The scale parameter. The default is 1.
@@ -745,11 +745,11 @@ class Gamma(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float, optional
             An optional argument to divide the residuals by sqrt(scale).
@@ -757,7 +757,7 @@ class Gamma(Family):
 
         Returns
         -------
-        resid_anscombe : array
+        resid_anscombe : ndarray
             The Anscombe residuals for the Gamma family defined below
 
         Notes
@@ -793,8 +793,8 @@ class Binomial(Family):
 
     See Also
     --------
-    statsmodels.genmod.families.family.Family
-    :ref:`links`
+    statsmodels.genmod.families.family.Family : Parent class for all links.
+    :ref:`links` : Further details on links.
 
     Notes
     -----
@@ -839,9 +839,9 @@ class Binomial(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             Endogenous response variable
-        freq_weights : array
+        freq_weights : ndarray
             1d array of frequency weights
 
         Returns
@@ -855,7 +855,11 @@ class Binomial(Family):
         '''
         # if not np.all(np.asarray(freq_weights) == 1):
         #     self.variance = V.Binomial(n=freq_weights)
-        if (endog.ndim > 1 and endog.shape[1] > 1):
+        if endog.ndim > 1 and endog.shape[1] > 2:
+            raise ValueError('endog has more than 2 columns. The Binomial '
+                             'link supports either a single response variable '
+                             'or a paired response variable.')
+        elif endog.ndim > 1 and endog.shape[1] > 1:
             y = endog[:, 0]
             # overwrite self.freq_weights for deviance below
             self.n = endog.sum(1)
@@ -869,9 +873,9 @@ class Binomial(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable.
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
 
         Returns
@@ -886,8 +890,8 @@ class Binomial(Family):
            resid\_dev_i = 2 * n * (endog_i * \ln(endog_i /\mu_i) +
            (1 - endog_i) * \ln((1 - endog_i) / (1 - \mu_i)))
         """
-        endog_mu = self._clean(endog / mu)
-        n_endog_mu = self._clean((1. - endog) / (1. - mu))
+        endog_mu = self._clean(endog / (mu + 1e-20))
+        n_endog_mu = self._clean((1. - endog) / (1. - mu + 1e-20))
         resid_dev = endog * np.log(endog_mu) + (1 - endog) * np.log(n_endog_mu)
         return 2 * self.n * resid_dev
 
@@ -898,11 +902,11 @@ class Binomial(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             Usually the endogenous response variable.
-        mu : array
+        mu : ndarray
             Usually but not always the fitted mean response variable.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float
             The scale parameter. The default is 1.
@@ -939,8 +943,9 @@ class Binomial(Family):
 
         # note that mu is still in (0,1), i.e. not converted back
         return (special.gammaln(n + 1) - special.gammaln(y + 1) -
-                special.gammaln(n - y + 1) + y * np.log(mu / (1 - mu)) +
-                n * np.log(1 - mu)) * var_weights
+                special.gammaln(n - y + 1) +
+                y * np.log(mu / (1 - mu + 1e-20)) +
+                n * np.log(1 - mu + 1e-20)) * var_weights
 
     def resid_anscombe(self, endog, mu, var_weights=1., scale=1.):
         r'''
@@ -948,11 +953,11 @@ class Binomial(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float, optional
             An optional argument to divide the residuals by sqrt(scale).
@@ -960,7 +965,7 @@ class Binomial(Family):
 
         Returns
         -------
-        resid_anscombe : array
+        resid_anscombe : ndarray
             The Anscombe residuals as defined below.
 
         Notes
@@ -1028,14 +1033,13 @@ class InverseGaussian(Family):
 
     See Also
     --------
-    statsmodels.genmod.families.family.Family
-    :ref:`links`
+    statsmodels.genmod.families.family.Family : Parent class for all links.
+    :ref:`links` : Further details on links.
 
     Notes
     -----
-    The inverse Guassian distribution is sometimes referred to in the
+    The inverse Gaussian distribution is sometimes referred to in the
     literature as the Wald distribution.
-
     """
 
     links = [L.inverse_squared, L.inverse_power, L.identity, L.log]
@@ -1054,9 +1058,9 @@ class InverseGaussian(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable.
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
 
         Returns
@@ -1079,11 +1083,11 @@ class InverseGaussian(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             Usually the endogenous response variable.
-        mu : array
+        mu : ndarray
             Usually but not always the fitted mean response variable.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float
             The scale parameter. The default is 1.
@@ -1113,11 +1117,11 @@ class InverseGaussian(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float, optional
             An optional argument to divide the residuals by sqrt(scale).
@@ -1125,7 +1129,7 @@ class InverseGaussian(Family):
 
         Returns
         -------
-        resid_anscombe : array
+        resid_anscombe : ndarray
             The Anscombe residuals for the inverse Gaussian distribution  as
             defined below
 
@@ -1166,8 +1170,8 @@ class NegativeBinomial(Family):
 
     See Also
     --------
-    statsmodels.genmod.families.family.Family
-    :ref:`links`
+    statsmodels.genmod.families.family.Family : Parent class for all links.
+    :ref:`links` : Further details on links.
 
     Notes
     -----
@@ -1202,9 +1206,9 @@ class NegativeBinomial(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable.
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
 
         Returns
@@ -1234,11 +1238,11 @@ class NegativeBinomial(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             Usually the endogenous response variable.
-        mu : array
+        mu : ndarray
             Usually but not always the fitted mean response variable.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float
             The scale parameter. The default is 1.
@@ -1285,11 +1289,11 @@ class NegativeBinomial(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float, optional
             An optional argument to divide the residuals by sqrt(scale).
@@ -1297,7 +1301,7 @@ class NegativeBinomial(Family):
 
         Returns
         -------
-        resid_anscombe : array
+        resid_anscombe : ndarray
             The Anscombe residuals as defined below.
 
         Notes
@@ -1356,12 +1360,12 @@ class Tweedie(Family):
 
     See Also
     --------
-    statsmodels.genmod.families.family.Family
-    :ref:`links`
+    statsmodels.genmod.families.family.Family : Parent class for all links.
+    :ref:`links` : Further details on links.
 
     Notes
     -----
-    Logliklihood function not implemented because of the complexity of
+    Loglikelihood function not implemented because of the complexity of
     calculating an infinite series of summations. The variance power can be
     estimated using the ``estimate_tweedie_power`` function that is part of the
     statsmodels.genmod.generalized_linear_model.GLM class.
@@ -1387,9 +1391,9 @@ class Tweedie(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable.
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
 
         Returns
@@ -1453,11 +1457,11 @@ class Tweedie(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             Usually the endogenous response variable.
-        mu : array
+        mu : ndarray
             Usually but not always the fitted mean response variable.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float
             The scale parameter. The default is 1.
@@ -1510,11 +1514,11 @@ class Tweedie(Family):
 
         Parameters
         ----------
-        endog : array
+        endog : ndarray
             The endogenous response variable
-        mu : array
+        mu : ndarray
             The inverse of the link function at the linear predicted values.
-        var_weights : array-like
+        var_weights : array_like
             1d array of variance (analytic) weights. The default is 1.
         scale : float, optional
             An optional argument to divide the residuals by sqrt(scale).
@@ -1522,7 +1526,7 @@ class Tweedie(Family):
 
         Returns
         -------
-        resid_anscombe : array
+        resid_anscombe : ndarray
             The Anscombe residuals as defined below.
 
         Notes
